# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]
### Added
- Application icon for the GUI (`OASIS Control Panel`), with bundled multi-resolution PNGs.


### Changed
- 

### Deprecated
- 

### Removed
- 

### Fixed
- 

### Security
- 

## [0.9.1] - 2025-09-09
### Fixed


## [0.9.0] - 2025-09-09
- Initial public pre-1.0 release (baseline).

## [0.9.0-a2] - 2025-08-20
### Added
- pyqt 6 rewrite
- Firmware-Version v3+ required

## [PyPI-v0.2.2] - 2025-05-05
- Release for Firmware-Version v2 boards

[Unreleased]: https://gitlab.com/oasis-acquisition/oasis-gui/-/compare/v0.9.1...main
[0.9.1]:        https://gitlab.com/oasis-acquisition/oasis-gui/-/tags/v0.9.1
[0.9.0]:        https://gitlab.com/oasis-acquisition/oasis-gui/-/tags/v0.9.0
[0.9.0-a2]:     https://gitlab.com/oasis-acquisition/oasis-gui/-/tags/v0.9.0-a2
